@@ -22,7 +22,7 @@ def load_config():
     sys.path.append(rootPath[0])
     sys.path.append(rootPath[0]+"/"+rootPath[1])
 
-    clickhouse_config_dir = rootPath[0]+"/"+rootPath[1]+"/"+"graph_config.json"
+    clickhouse_config_dir = rootPath[0]+"/"+rootPath[1]+"/config/"+"graph_config.json"
 
     with open(clickhouse_config_dir, 'r') as f:
         clickhouse_config = ujson.load(f)
